==> ejc-accplat-impl-3.0.0-20231219.081400-23-sources.jar: com/ejianc/business/voucher/transfer/BaseVoucherTransferService.java <==
package com.ejianc.business.voucher.transfer;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.accplat.bean.BillAccbookSetEntity;
import com.ejianc.business.accplat.bean.BillAuxiliarySetEntity;
import com.ejianc.business.accplat.bean.BillInfluenceSetEntity;
import com.ejianc.business.accplat.service.IBillAccbookSetService;
import com.ejianc.business.accplat.service.IBillAuxiliarySetService;
import com.ejianc.business.accplat.service.IBillInfluenceSetService;
import com.ejianc.business.accplat.vo.BillAccbookSetVO;
import com.ejianc.business.accplat.vo.BillAuxiliarySetVO;
import com.ejianc.business.accplat.vo.BillInfluenceSetVO;
import com.ejianc.business.accplat.vo.VoucherTemplateVO;
import com.ejianc.business.voucher.service.IFinanceVoucherService;
import com.ejianc.business.voucher.service.VoucherTemplateCacheProvider;
import com.ejianc.business.voucher.vo.VoucherParams;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @description: 公共凭证转化服务
 *  * 1、依据凭证模板转化原始凭证
 *  * 2、依据原始凭证转化财务凭证
 * @author songlx
 * @date 2023/11/28
 * @version 1.0
 */
@Slf4j
public class BaseVoucherTransferService {

    @Autowired
    private VoucherServiceFactory voucherServiceFactory;

    @Autowired
    private VoucherTemplateCacheProvider voucherTemplateCacheProvider;

    @Autowired
    private IBillAccbookSetService billAccbookSetService;

    @Autowired
    private IBillInfluenceSetService billInfluenceSetService;

    @Autowired
    private IBillAuxiliarySetService billAuxiliarySetService;

    @Autowired
    private IOrgApi orgApi;


    /**
     * @description: 获取辅助核算项关联
     *
     * @param voucherParams
     * @return {@link List< BillAuxiliarySetVO>}
     * @author songlx
     * @date: 2023/12/18
     */
    public List<BillAuxiliarySetVO> getBillAuxiliarySet(VoucherParams voucherParams) {
        String billTypeCode = voucherParams.getBillTypeCode();
        LambdaQueryWrapper<BillAuxiliarySetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillAuxiliarySetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillAuxiliarySetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        List<BillAuxiliarySetEntity> list = billAuxiliarySetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【辅助核算项关联】");
        }
        return BeanMapper.mapList(list, BillAuxiliarySetVO.class);
    }


    /**
     * @description: 获取影响因素关联
     *
     * @param voucherParams
     * @return {@link List< BillInfluenceSetVO>}
     * @author songlx
     * @date: 2023/12/18
     */
    public List<BillInfluenceSetVO> getBillInfluenceSet(VoucherParams voucherParams) {
        String billTypeCode = voucherParams.getBillTypeCode();
        LambdaQueryWrapper<BillInfluenceSetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillInfluenceSetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillInfluenceSetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        List<BillInfluenceSetEntity> list = billInfluenceSetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【影响因素关联】");
        }
        return BeanMapper.mapList(list, BillInfluenceSetVO.class);
    }


    /**
     * @description: 获取账簿设置
     *
     * @param voucherParams
     * @return {@link List< BillAccbookSetVO>}
     * @author songlx
     * @date: 2023/12/18
     */
    public List<BillAccbookSetVO> getBillAccbookSet(VoucherParams voucherParams) {
        String billTypeCode = voucherParams.getBillTypeCode();
        LambdaQueryWrapper<BillAccbookSetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillAccbookSetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillAccbookSetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        List<BillAccbookSetEntity> list = billAccbookSetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【账簿映射规则】");
        }
        return BeanMapper.mapList(list, BillAccbookSetVO.class);
    }


    /**
     * @description: 获取当前组织的账簿，递归最近上级获取
     *
     * @param orgId
     * @param billTypeCode
     * @return {@link BillAccbookSetVO}
     * @author songlx
     * @date: 2023/12/18
     */
    protected BillAccbookSetVO getBillAccbookSet(Long orgId, String billTypeCode) {
        CommonResponse<OrgVO> oneById = orgApi.getOneById(orgId);
        OrgVO orgVO = oneById.getData();
        String[] parentOrgIds = orgVO.getInnerCode().split("\\|");

        LambdaQueryWrapper<BillAccbookSetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillAccbookSetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillAccbookSetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        wrapper.in(BillAccbookSetEntity::getSourceOrgId, parentOrgIds);
        List<BillAccbookSetEntity> list = billAccbookSetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【账簿映射规则】, orgId:" + orgId);
        }
        Map<Long, BillAccbookSetEntity> setMap = list.stream().collect(Collectors.toMap(BillAccbookSetEntity::getSourceOrgId, Function.identity(), (key1, key2) -> key2));
        BillAccbookSetVO billAccbookSetVO = null;
        for (int i = parentOrgIds.length - 1; i >= 0; i--) {
            BillAccbookSetEntity billAccbookSetEntity = setMap.get(Long.valueOf(parentOrgIds[i]));
            if(billAccbookSetEntity != null){
                billAccbookSetVO = BeanMapper.map(billAccbookSetEntity, BillAccbookSetVO.class);
                break;
            }
        }
        return billAccbookSetVO;
    }


    /**
     * @description: 转化方法
     * @author songlx
     * @date: 2023/11/29
     */
    public void transfer(VoucherParams voucherParams) {
        voucherParams.setIsGenerateOriginVoucherFlag(getIsGenerateOriginVoucherFlag(voucherParams));
        voucherParams.setIsGenerateFinanceVoucherFlag(getIsGenerateFinanceVoucherFlag(voucherParams));
        if (voucherParams.getIsGenerateOriginVoucherFlag()) {
            transferOriginVoucher(voucherParams);
        }
        if (voucherParams.getIsGenerateFinanceVoucherFlag()) {
            transferFinanceVoucher(voucherParams);
        }
    }


    /**
     * @description: 转化原始凭证，子类复写，有以下两种情况
     * 1、公共CommonVoucherTransferService 根据凭证模板转化原始凭证，可以直接调用transferOriginVoucherByVoucherTemplate
     * 2、自定义转化服务（如SubSettleVoucherCustomTransferService）可以根据定义分录转化原始凭证，
     *    如不需要复写getIsGenerateOriginVoucherFlag返回false
     * @param voucherParams
     * @return
     * @author songlx
     * @date: 2023/12/1
     */
    public void transferOriginVoucher(VoucherParams voucherParams) {
        this.transferOriginVoucherByVoucherTemplate(voucherParams);
    }


    /**
     * @description: 转化财务凭证，子类复写，有以下两种情况
     * 1、公共CommonVoucherTransferService 根据原始凭证转化财务凭证，可以直接调用transferFinanceVoucherByOriginVoucher
     * 2、自定义转化服务（如SubSettleVoucherCustomTransferService）可以根据定义分录直接转化财务凭证（或者自定义也转化了原始凭证，可以直接调用transferFinanceVoucherByOriginVoucher），
     *    如不需要复写getIsGenerateFinanceVoucherFlag返回false
     * @param voucherParams
     * @return
     * @author songlx
     * @date: 2023/12/1
     */
    public void transferFinanceVoucher(VoucherParams voucherParams) {
        this.transferFinanceVoucherByOriginVoucher(voucherParams);
    }


    /**
     * @description: 依据凭证模板转化原始凭证
     * @author songlx
     * @date: 2023/11/29
     */
    private void transferOriginVoucherByVoucherTemplate(VoucherParams voucherParams) {
        VoucherTemplateVO voucherTemplateVO = voucherTemplateCacheProvider.loadTemplateFromCache(InvocationInfoProxy.getTenantid(), voucherParams.getBillTypeCode());
        voucherParams.setOriginVoucher(null);
    }


    /**
     * @description: 依据原始凭证转化财务凭证
     *
     * @author songlx
     * @date: 2023/11/29
     */
    public void transferFinanceVoucherByOriginVoucher(VoucherParams voucherParams) {
        String systemCode = voucherParams.getSystemCode();
        IFinanceVoucherService financeVoucherService = voucherServiceFactory.getFinanceVoucherService(systemCode);
        financeVoucherService.convertToFinanceVoucherByOriginVoucher(voucherParams);
    }


    /**
     * @description: 是否生成原始凭证，如为true，请在transferOriginVoucher中转化
     * @author songlx
     * @date: 2023/11/29
     */
    public Boolean getIsGenerateOriginVoucherFlag(VoucherParams voucherParams) {
        return Boolean.TRUE;
    }


    /**
     * @description: 是否生成财务凭证，如为true，请在transferFinanceVoucher中转化
     * 后续可能改成配置参数获取
     * @author songlx
     * @date: 2023/11/29
     */
    public Boolean getIsGenerateFinanceVoucherFlag(VoucherParams voucherParams) {
        return Boolean.TRUE;
    }


}

==> ejc-accplat-impl-3.0.0-20231222.030955-46-sources.jar: com/ejianc/business/voucher/transfer/BaseVoucherTransferService.java <==
package com.ejianc.business.voucher.transfer;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.accplat.bean.BillAccbookSetEntity;
import com.ejianc.business.accplat.bean.BillAuxiliarySetEntity;
import com.ejianc.business.accplat.bean.BillInfluenceSetEntity;
import com.ejianc.business.accplat.service.IBillAccbookSetService;
import com.ejianc.business.accplat.service.IBillAuxiliarySetService;
import com.ejianc.business.accplat.service.IBillInfluenceSetService;
import com.ejianc.business.accplat.service.ISubjectContrastService;
import com.ejianc.business.accplat.vo.*;
import com.ejianc.business.voucher.dto.EntriesDTO;
import com.ejianc.business.voucher.service.IFinanceVoucherService;
import com.ejianc.business.voucher.service.VoucherTemplateCacheProvider;
import com.ejianc.business.voucher.vo.VoucherParams;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ComputeUtil;
import com.googlecode.aviator.AviatorEvaluator;
import com.googlecode.aviator.Expression;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

import java.math.BigDecimal;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @description: 公共凭证转化服务
 *  * 1、依据凭证模板转化原始凭证
 *  * 2、依据原始凭证转化财务凭证
 * @author songlx
 * @date 2023/11/28
 * @version 1.0
 */
@Slf4j
public class BaseVoucherTransferService {

    @Autowired
    private VoucherServiceFactory voucherServiceFactory;

    @Autowired
    private VoucherTemplateCacheProvider voucherTemplateCacheProvider;

    @Autowired
    private IBillAccbookSetService billAccbookSetService;

    @Autowired
    private IBillInfluenceSetService billInfluenceSetService;

    @Autowired
    private IBillAuxiliarySetService billAuxiliarySetService;

    @Autowired
    private IOrgApi orgApi;

    @Autowired
    private ISubjectContrastService subjectContrastService;


    public Map<String, EntriesDTO> analysisEntries(String billTypeCode, String subjectCategoryCode, Map<String, Object> billData, String mainMnyColName, String subMnyColName) {
        BigDecimal mny = ComputeUtil.toBigDecimal(billData.get(mainMnyColName));
        log.info("==========解析分录【科目分类编码：" + subjectCategoryCode + "】=====start====================================");
        // 2、借方
        Map<String, EntriesDTO> debitMap = new LinkedHashMap<>();
        SubjectContrastVO subjectContrast = this.getSubjectContrast(null, subjectCategoryCode);
        List<SubjectContrastDetailVO> subjectContrastDetailList = subjectContrast.getSubjectContrastDetailList();
        List<BillInfluenceSetVO> billInfluenceSetList = this.getBillInfluenceSet(billTypeCode);
        Map<Long, String> billInfluenceSetMap = billInfluenceSetList.stream().collect(Collectors.toMap(BillInfluenceSetVO::getInfluenceId, msg -> msg.getColumnExpression()));

        if (CollectionUtils.isEmpty(subjectContrastDetailList)) {
            String defaultSubjectCode = subjectContrast.getDefaultSubjectCode();
            if (debitMap.containsKey(defaultSubjectCode)) {
                EntriesDTO entriesDTO = debitMap.get(defaultSubjectCode);
                entriesDTO.setMny(ComputeUtil.safeAdd(entriesDTO.getMny(), mny));
            } else {
                EntriesDTO debitDTO = EntriesDTO.newDebitDTO(defaultSubjectCode);
                debitDTO.setMny(mny);
                debitMap.put(defaultSubjectCode, debitDTO);
            }
        } else {
            for (SubjectContrastDetailVO subjectContrastDetailVO : subjectContrastDetailList) {
                String accountSubjectCode = subjectContrastDetailVO.getAccountSubjectCode();
                List<SubjectContrastDetailInfluenceVO> subjectContrastDetailInfluenceList = subjectContrastDetailVO.getSubjectContrastDetailInfluenceList();
                List expressionList = new LinkedList<String>();
                String expressionString = null;
                for (SubjectContrastDetailInfluenceVO subjectContrastDetailInfluenceVO : subjectContrastDetailInfluenceList) {
                    Long influenceId = subjectContrastDetailInfluenceVO.getInfluenceId();
                    String influenceValue = subjectContrastDetailInfluenceVO.getInfluenceValue();
                    String columnExpression = billInfluenceSetMap.get(influenceId);
                    if (StringUtils.isBlank(columnExpression)) {
                        throw new BusinessException("会计平台配置-影响因素关联未配置字段【" + columnExpression + "】");
                    }
                    expressionList.add(columnExpression + "==" + influenceValue);
                    expressionString = "'" + columnExpression + " : '  + " + columnExpression;
                    Expression expression1 = AviatorEvaluator.getInstance().compile(expressionString);
                    Object execute = expression1.execute(billData);
                    log.info(execute.toString());
                }
                expressionString = String.join(" && ", expressionList);
                // 编译表达式
                Expression expression = AviatorEvaluator.getInstance().compile(expressionString);
                boolean b = (boolean) expression.execute(billData);
                log.info(expressionString + ": " + b);
                if (b) {
                    EntriesDTO debitDTO = EntriesDTO.newDebitDTO(accountSubjectCode);
                    debitDTO.setMny(mny);
                    if (debitMap.containsKey(accountSubjectCode)) {
                        EntriesDTO entriesDTO = debitMap.get(accountSubjectCode);
                        entriesDTO.setMny(ComputeUtil.safeAdd(entriesDTO.getMny(), mny));
                    } else {
                        EntriesDTO debitDTO1 = EntriesDTO.newDebitDTO(accountSubjectCode);
                        debitDTO1.setMny(mny);
                        debitMap.put(accountSubjectCode, debitDTO1);
                    }

                }
            }
        }
        log.info("==========解析分录【科目分类编码：" + subjectCategoryCode + "】=====end======================================");
        return debitMap;
    }


    /**
     * @description: 根据科目表编码和科目分类编码获取科目对照
     *
     * @param subjectChartCode
     * @param subjectCategoryCode
     * @return {@link SubjectContrastVO}
     * @author songlx
     * @date: 2023/12/20
     */
    public SubjectContrastVO getSubjectContrast(String subjectChartCode, String subjectCategoryCode) {
        return subjectContrastService.getOneBySubjectCategoryCode(subjectChartCode, subjectCategoryCode);
    }


    /**
     * @description: 获取辅助核算项关联
     *
     * @param billTypeCode
     * @return {@link List< BillAuxiliarySetVO>}
     * @author songlx
     * @date: 2023/12/18
     */
    public List<BillAuxiliarySetVO> getBillAuxiliarySet(String billTypeCode) {
        LambdaQueryWrapper<BillAuxiliarySetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillAuxiliarySetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillAuxiliarySetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        List<BillAuxiliarySetEntity> list = billAuxiliarySetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【辅助核算项关联】");
        }
        return BeanMapper.mapList(list, BillAuxiliarySetVO.class);
    }


    /**
     * @description: 获取影响因素关联
     *
     * @param billTypeCode
     * @return {@link List< BillInfluenceSetVO>}
     * @author songlx
     * @date: 2023/12/18
     */
    public List<BillInfluenceSetVO> getBillInfluenceSet(String billTypeCode) {
        LambdaQueryWrapper<BillInfluenceSetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillInfluenceSetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillInfluenceSetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        List<BillInfluenceSetEntity> list = billInfluenceSetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【影响因素关联】");
        }
        return BeanMapper.mapList(list, BillInfluenceSetVO.class);
    }


    /**
     * @description: 获取当前组织的账簿，递归最近上级获取
     *
     * @param orgId
     * @param billTypeCode
     * @return {@link BillAccbookSetVO}
     * @author songlx
     * @date: 2023/12/18
     */
    protected BillAccbookSetVO getBillAccbookSet(Long orgId, String billTypeCode) {
        CommonResponse<OrgVO> oneById = orgApi.getOneById(orgId);
        OrgVO orgVO = oneById.getData();
        String[] parentOrgIds = orgVO.getInnerCode().split("\\|");

        LambdaQueryWrapper<BillAccbookSetEntity> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(BillAccbookSetEntity::getBillTypeCode, billTypeCode);
        wrapper.eq(BillAccbookSetEntity::getTenantId, InvocationInfoProxy.getTenantid());
        wrapper.in(BillAccbookSetEntity::getSourceOrgId, parentOrgIds);
        List<BillAccbookSetEntity> list = billAccbookSetService.list(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            throw new BusinessException("未获取到【账簿映射规则】, orgId:" + orgId);
        }
        Map<Long, BillAccbookSetEntity> setMap = list.stream().collect(Collectors.toMap(BillAccbookSetEntity::getSourceOrgId, Function.identity(), (key1, key2) -> key2));
        BillAccbookSetVO billAccbookSetVO = null;
        for (int i = parentOrgIds.length - 1; i >= 0; i--) {
            BillAccbookSetEntity billAccbookSetEntity = setMap.get(Long.valueOf(parentOrgIds[i]));
            if (billAccbookSetEntity != null) {
                billAccbookSetVO = BeanMapper.map(billAccbookSetEntity, BillAccbookSetVO.class);
                break;
            }
        }
        return billAccbookSetVO;
    }


    /**
     * @description: 转化方法
     * @author songlx
     * @date: 2023/11/29
     */
    public void transfer(VoucherParams voucherParams) {
        voucherParams.setIsGenerateOriginVoucherFlag(getIsGenerateOriginVoucherFlag(voucherParams));
        voucherParams.setIsGenerateFinanceVoucherFlag(getIsGenerateFinanceVoucherFlag(voucherParams));
        if (voucherParams.getIsGenerateOriginVoucherFlag()) {
            transferOriginVoucher(voucherParams);
        }
        if (voucherParams.getIsGenerateFinanceVoucherFlag()) {
            transferFinanceVoucher(voucherParams);
        }
    }


    /**
     * @description: 转化原始凭证，子类复写，有以下两种情况
     * 1、公共CommonVoucherTransferService 根据凭证模板转化原始凭证，可以直接调用transferOriginVoucherByVoucherTemplate
     * 2、自定义转化服务（如SubSettleVoucherCustomTransferService）可以根据定义分录转化原始凭证，
     *    如不需要复写getIsGenerateOriginVoucherFlag返回false
     * @param voucherParams
     * @return
     * @author songlx
     * @date: 2023/12/1
     */
    public void transferOriginVoucher(VoucherParams voucherParams) {
        this.transferOriginVoucherByVoucherTemplate(voucherParams);
    }


    /**
     * @description: 转化财务凭证，子类复写，有以下两种情况
     * 1、公共CommonVoucherTransferService 根据原始凭证转化财务凭证，可以直接调用transferFinanceVoucherByOriginVoucher
     * 2、自定义转化服务（如SubSettleVoucherCustomTransferService）可以根据定义分录直接转化财务凭证（或者自定义也转化了原始凭证，可以直接调用transferFinanceVoucherByOriginVoucher），
     *    如不需要复写getIsGenerateFinanceVoucherFlag返回false
     * @param voucherParams
     * @return
     * @author songlx
     * @date: 2023/12/1
     */
    public void transferFinanceVoucher(VoucherParams voucherParams) {
        this.transferFinanceVoucherByOriginVoucher(voucherParams);
    }


    /**
     * @description: 依据凭证模板转化原始凭证
     * @author songlx
     * @date: 2023/11/29
     */
    private void transferOriginVoucherByVoucherTemplate(VoucherParams voucherParams) {
        VoucherTemplateVO voucherTemplateVO = voucherTemplateCacheProvider.loadTemplateFromCache(InvocationInfoProxy.getTenantid(), voucherParams.getBillTypeCode());
        voucherParams.setOriginVoucher(null);
    }


    /**
     * @description: 依据原始凭证转化财务凭证
     *
     * @author songlx
     * @date: 2023/11/29
     */
    public void transferFinanceVoucherByOriginVoucher(VoucherParams voucherParams) {
        String systemCode = voucherParams.getSystemCode();
        IFinanceVoucherService financeVoucherService = voucherServiceFactory.getFinanceVoucherService(systemCode);
        financeVoucherService.convertToFinanceVoucherByOriginVoucher(voucherParams);
    }


    /**
     * @description: 是否生成原始凭证，如为true，请在transferOriginVoucher中转化
     * @author songlx
     * @date: 2023/11/29
     */
    public Boolean getIsGenerateOriginVoucherFlag(VoucherParams voucherParams) {
        return Boolean.TRUE;
    }


    /**
     * @description: 是否生成财务凭证，如为true，请在transferFinanceVoucher中转化
     * 后续可能改成配置参数获取
     * @author songlx
     * @date: 2023/11/29
     */
    public Boolean getIsGenerateFinanceVoucherFlag(VoucherParams voucherParams) {
        return Boolean.TRUE;
    }


}
